@@ -1,6 +1,6 @@
 package Bundle::COG;
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 =head1 NAME
 
@@ -14,22 +14,22 @@ cpan Bundle::COG
 
 Acme::AsciiArt2HtmlTable
 
+Acme::BooK::Is::My::Bitch
+
 Business::PT::BI
 
 Business::PT::NIF
 
 Date::Holidays::PT
 
-File::Munger
-
 Filesys::DiskUsage
 
 Filesys::Tree
 
-Games::PetalsAroundTheRose
-
 Games::Messages
 
+Games::PetalsAroundTheRose
+
 Games::Score
 
 Lingua::Identify
@@ -50,16 +50,12 @@ Mail::LocalDelivery
 
 Number::Phone::PT
 
-PT::PostalCode
-
 Test::RandomResults
 
 Text::Affixes
 
 Text::Beautify
 
-Text::Ngram
-
 WWW::Dictionary
 
 =head1 AUTHOR
